@@ -3,16 +3,12 @@
  Documentation generator for the Lua/APR binding.
 
  Author: Peter Odding <peter@peterodding.com>
- Last Change: March 28, 2011
+ Last Change: June 19, 2011
  Homepage: http://peterodding.com/code/lua/apr/
  License: MIT
 
 ]]
 
--- We only need this for the version number.
--- TODO Might as well extract it directly from apr.lua?
-local apr = require 'apr'
-
 -- Files containing documentation fragments (the individual lines enable
 -- automatic rebasing between git feature branches and the master branch).
 local SOURCES = [[
@@ -244,6 +240,19 @@ end
 
 -- Convert documentation comments to Markdown hypertext. {{{1
 
+local function findrelease()
+  local handle = assert(io.open 'src/apr.lua')
+  local version, release
+  for line in handle:lines() do
+    version = version or line:match "^apr%._VERSION = '(.-)'"
+    release = release or line:match "^apr%._RELEASE = '(.-)'"
+  end
+  assert(handle:close())
+  assert(version, "Failed to determine Lua/APR version number!")
+  assert(release, "Failed to determine Lua/APR release number!")
+  return version .. '-' .. release
+end
+
 local blocks = { trim([[
 
 # Lua/APR binding documentation
@@ -262,7 +271,7 @@ for the Lua/APR binding. Some notes about this documentation:
    source code of the binding to prevent that documentation and implementation
    become out of sync.
 
-*This document was generated from the Lua/APR **]] .. apr._VERSION .. [[** source code.*
+*This document was generated from the Lua/APR **]] .. findrelease() .. [[** source code.*
 
 [homepage]: http://peterodding.com/code/lua/apr/
 [apr_wiki]: http://en.wikipedia.org/wiki/Apache_Portable_Runtime
@@ -443,6 +452,15 @@ local function htmlencode(s)
            :gsub('>', '&gt;'))
 end
 
+local custom_sorting = {
+  ['crypt.c'] = [[ apr.md5 apr.md5_encode apr.password_validate
+    apr.password_get apr.md5_init md5_context:update md5_context:digest
+    md5_context:reset apr.sha1 apr.sha1_init sha1_context:update
+    sha1_context:digest sha1_context:reset ]],
+  ['thread.c'] = [[ apr.thread apr.thread_create apr.thread_yield
+    thread:status thread:join ]],
+}
+
 for _, module in ipairs(sorted_modules) do
 
   local a = toanchor(module.name)
@@ -452,14 +470,9 @@ for _, module in ipairs(sorted_modules) do
     blocks:add('    %s', module.example:gsub('\n', '\n    '))
   end
 
-  if module.file == 'crypt.c' then
-    -- Custom sorting for the cryptography module.
-    local orderstr = [[ apr.md5 apr.md5_encode apr.password_validate
-        apr.password_get apr.md5_init md5_context:update md5_context:digest
-        md5_context:reset apr.sha1 apr.sha1_init sha1_context:update
-        sha1_context:digest sha1_context:reset ]]
+  if custom_sorting[module.file] then
     local ordertbl = { n = 0 }
-    for f in orderstr:gmatch '%S+' do
+    for f in custom_sorting[module.file]:gmatch '%S+' do
       ordertbl[f], ordertbl.n = ordertbl.n, ordertbl.n + 1
     end
     local function order(f)
