@@ -3,7 +3,7 @@
  Lua source code for the Lua/APR binding.
 
  Author: Peter Odding <peter@peterodding.com>
- Last Change: June 16, 2011
+ Last Change: June 19, 2011
  Homepage: http://peterodding.com/code/lua/apr/
  License: MIT
 
@@ -14,8 +14,8 @@
 --]]
 
 local apr = require 'apr.core'
-apr._VERSION = '0.18'
-apr._RELEASE = '2'
+apr._VERSION = '0.18.2'
+apr._RELEASE = '1'
 
 -- apr.md5(input [, binary]) -> digest {{{1
 --
@@ -280,6 +280,27 @@ function apr.getopt(usage, config)
   end
 end
 
+if apr.thread_create then
+
+-- apr.thread(body [, arg, ...]) -> thread {{{1
+--
+-- Shortcut for `apr.thread_create()` that supports actual functions as @body
+-- by converting them to byte code using `string.dump()`. This means you don't
+-- lose syntax highlighting and debug information. This also calls `assert()`
+-- on the results of `apr.thread_create()`. This function won't work in Lua
+-- implementations like LuaJIT 2 where `string.dump()` is not available.
+--
+-- Part of the "Multi threading" module.
+
+function apr.thread(body, ...)
+  if type(body) == 'function' then
+    body = string.dump(body)
+  end
+  return assert(apr.thread_create(body, ...))
+end
+
+end
+
 -- }}}1
 
 return apr
