@@ -1,7 +1,7 @@
 /* Thread queues module for the Lua/APR binding.
  *
  * Author: Peter Odding <peter@peterodding.com>
- * Last Change: February 19, 2011
+ * Last Change: June 16, 2011
  * Homepage: http://peterodding.com/code/lua/apr/
  * License: MIT
  *
@@ -24,7 +24,7 @@ typedef struct {
 
 /* Internal functions. {{{1 */
 
-static void close_queue_real(lua_State *L, lua_apr_queue *object)
+static void close_queue_real(lua_apr_queue *object)
 {
   if (object_collectable((lua_apr_refobj*)object)) {
     if (object->pool != NULL) {
@@ -32,7 +32,7 @@ static void close_queue_real(lua_State *L, lua_apr_queue *object)
       object->pool = NULL;
     }
   }
-  release_object(L, (lua_apr_refobj*)object);
+  release_object((lua_apr_refobj*)object);
 }
 
 typedef apr_status_t (lua_apr_cc *apr_queue_push_func)(apr_queue_t*, void*);
@@ -159,6 +159,41 @@ static int queue_trypop(lua_State *L)
   return queue_pop_real(L, apr_queue_trypop);
 }
 
+/* queue:interrupt() -> status {{{1
+ *
+ * Interrupt all the threads blocking on this queue. On success true is
+ * returned, otherwise a nil followed by an error message is returned.
+ */
+
+static int queue_interrupt(lua_State *L)
+{
+  apr_status_t status;
+  lua_apr_queue *object;
+  
+  object = check_queue(L, 1);
+  status = apr_queue_interrupt_all(object->handle);
+
+  return push_status(L, status);
+}
+
+/* queue:terminate() -> status {{{1
+ *
+ * Terminate the queue, sending an interrupt to all the blocking threads. On
+ * success true is returned, otherwise a nil followed by an error message is
+ * returned.
+ */
+
+static int queue_terminate(lua_State *L)
+{
+  apr_status_t status;
+  lua_apr_queue *object;
+  
+  object = check_queue(L, 1);
+  status = apr_queue_term(object->handle);
+
+  return push_status(L, status);
+}
+
 /* queue:close() -> status {{{1
  *
  * Close the handle @queue and (if no other threads are using the queue)
@@ -172,7 +207,7 @@ static int queue_trypop(lua_State *L)
 
 static int queue_close(lua_State *L)
 {
-  close_queue_real(L, check_queue(L, 1));
+  close_queue_real(check_queue(L, 1));
   lua_pushboolean(L, 1);
   return 1;
 }
@@ -190,7 +225,7 @@ static int queue_tostring(lua_State *L)
 
 static int queue_gc(lua_State *L)
 {
-  close_queue_real(L, check_queue(L, 1));
+  close_queue_real(check_queue(L, 1));
   return 0;
 }
 
@@ -201,6 +236,8 @@ static luaL_Reg queue_methods[] = {
   { "pop", queue_pop },
   { "trypush", queue_trypush },
   { "trypop", queue_trypop },
+  { "interrupt", queue_interrupt },
+  { "terminate", queue_terminate },
   { "close", queue_close },
   { NULL, NULL }
 };
